﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.Http;
using HeuristicLab.Services.Access;
using HeuristicLab.Services.Hive;
using HeuristicLab.Services.Hive.DataAccess.Interfaces;
using DTO = HeuristicLab.Services.WebApp.Statistics.WebApi.DataTransfer;

namespace HeuristicLab.Services.WebApp.Statistics.WebApi {

  [Authorize]
  public class DataController : ApiController {

    private IPersistenceManager PersistenceManager {
      get { return ServiceLocator.Instance.PersistenceManager; }
    }

    private IUserManager UserManager {
      get { return ServiceLocator.Instance.UserManager; }
    }

    public IEnumerable<DTO.Job> GetJobs() {
      return GetJobsByUserId(UserManager.CurrentUserId);
    }

    public IEnumerable<DTO.Job> GetJobsByUserId(Guid id) {
      using (var pm = PersistenceManager) {
        return pm.UseTransaction(() => {
          var dimJobDao = pm.DimJobDao;
          return dimJobDao.GetByUserId(id).Select(x => new DTO.Job {
            Id = x.JobId,
            Name = x.JobName,
            DateCreated = x.DateCreated
          }).ToList();
        });
      }
    }

    public IEnumerable<DTO.Task> GetTasksByJobId(Guid id) {
      using (var pm = PersistenceManager) {
        return pm.UseTransaction(() => {
          var factTaskDao = pm.FactTaskDao;
          return factTaskDao.GetByJobId(id).Select(x => new DTO.Task {
            TotalRuntime = x.TotalRuntime,
            TotalWaitingTime = x.TotalWaitingTime,
            TotalTransferTime = x.TotalTransferTime,
            NumCalculationRuns = x.NumCalculationRuns,
            NumRetries = x.NumRetries,
            CoresRequired = x.CoresRequired,
            MemoryRequired = x.MemoryRequired,
            Priority = x.Priority,
            LastClientId = x.LastClientId,
            StartTime = x.StartTime,
            EndTime = x.EndTime
          }).ToList();
        });
      }
    }

  }
}
